@@ -23,10 +23,10 @@ from fastapi.responses import ORJSONResponse
 from pydantic import BaseModel as PydanticBaseModel
 from pydantic import create_model
 from pypika.terms import Term
-from tortoise.expressions import RawSQL
-from tortoise.functions import Function
-from tortoise.models import Field, MetaInfo
-from tortoise.queryset import Q, QuerySet
+from tortoise.expressions import Function, Q, RawSQL
+from tortoise.fields.base import Field
+from tortoise.models import MetaInfo
+from tortoise.queryset import QuerySet
 from tortoise.transactions import in_transaction
 
 from .. import json
@@ -64,6 +64,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
         enable_update: bool = True,
         enable_delete: bool = True,
         enable_get: bool = True,
+        enable_summary: bool = False,
     ) -> None:
         super().__init__()
         self.model = model
@@ -74,6 +75,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
         self.enable_update = enable_update
         self.enable_delete = enable_delete
         self.enable_get = enable_get
+        self.enable_summary = enable_summary
 
     async def translate_id(self, user: UserModel, id: str, request: Request) -> str:
         return id
@@ -89,7 +91,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
         return v
 
     def group_by_f(
-        self, group_by: str, field: Field
+        self, group_by: str, field: Field[Any]
     ) -> Optional[Union[Function, Term]]:
         return None
 
@@ -101,12 +103,13 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
         group_by: List[str],
     ):
         model_meta: MetaInfo = getattr(q.model, "_meta")
-        field_names: Iterable[str] = include or model_meta.fields_map.keys()
+        fields_map: Dict[str, Field[Any]] = getattr(model_meta, "fields_map")
+        field_names: Iterable[str] = include or fields_map.keys()
         annotates: Dict[str, Union[Function, Term]] = {}
         for field_name in field_names:
             if field_name in group_by:
                 continue
-            field = model_meta.fields_map[field_name]
+            field = fields_map[field_name]
             annotate = self.group_by_f(field_name, field)
             if annotate is None:
                 continue
@@ -115,6 +118,20 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
         q = q.group_by(*group_by)
         return annotates, q
 
+    async def grouping(
+        self,
+        user: UserModel,
+        q: QuerySet[Model],
+        include: Iterable[str],
+        group_by: List[str],
+    ) -> List[Model]:
+        annotates, group_by_q = self.group_by(user, q, include, group_by)
+        dicts = await group_by_q.values(*group_by, *annotates.keys())
+        return [
+            self.model(**{k: v for k, v in dic.items() if v is not None})
+            for dic in dicts
+        ]
+
     def q(
         self,
         user: UserModel,
@@ -284,6 +301,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
             f"{self.model.__module__}.{self.model.__name__}.Response",
             __base__=PydanticBaseModel,
             total=0,
+            summary=(Optional[ListPydanticModel], ...),  # type: ignore
             data=(List[ListPydanticModel], ...),  # type: ignore
         )
 
@@ -391,6 +409,7 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                 request: Request,
                 offset: int = Query(0, title="分页偏移"),
                 limit: int = Query(20, title="分页限额"),
+                include_summary: bool = Query(False, title="是否包含summary数据"),
                 condition: List[str] = Query([], title="查询条件", description=help),
                 order_by: List[str] = Query(
                     [],
@@ -418,6 +437,13 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                 if include:
                     q = q.only(*include)
 
+                summary: Optional[Model] = None
+                include_summary = self.enable_summary and include_summary
+                if include_summary:
+                    objs = await self.grouping(current_user, q, include, [])
+                    if objs:
+                        summary = objs[0]
+
                 if group_by:
                     group_by_fields = ",".join([f"`{field}`" for field in group_by])
                     total_q = q.annotate(
@@ -440,21 +466,19 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
 
                 q = q.offset(offset).limit(limit)
                 if group_by:
-                    annotates, q = self.group_by(current_user, q, include, group_by)
-                    dicts = cast(
-                        List[Dict[str, Any]],
-                        await q.values(*group_by, *annotates.keys()),
-                    )
-                    objs = [self.model(**v) for v in dicts]
+                    objs = await self.grouping(current_user, q, include, group_by)
                 else:
                     objs = await q
 
                 if prefetch:
                     for obj in objs:
                         await obj.fetch_related(*prefetch)
+                    if summary:
+                        await summary.fetch_related(*prefetch)
 
                 return Response(
                     total=total,
+                    summary=summary and ListPydanticModel.from_orm(summary),
                     data=[ListPydanticModel.from_orm(obj) for obj in objs],
                 )
 
@@ -509,19 +533,24 @@ class API(Generic[UserModel, Model, CreateForm, UpdateForm]):
                         if r:
                             obj = r
                             raw = input.dict(exclude_unset=True)
+
                             updated_at = raw.pop("updated_at", None)
                             if updated_at:
                                 # 防止老数据修改
                                 if isinstance(updated_at, str):
                                     updated_at = json.parse_iso_datetime(updated_at)
                                 if isinstance(updated_at, datetime):
-                                    obj_updated_at = obj.updated_at.replace(
-                                        microsecond=int(
-                                            str(obj.updated_at.microsecond)[:3]
-                                        )
+                                    obj_updated_at: Optional[datetime] = getattr(
+                                        obj, "updated_at", None
                                     )
-                                    if obj_updated_at > updated_at:
-                                        raise HTTPPreconditionRequiredError
+                                    if obj_updated_at:
+                                        obj_updated_at = obj_updated_at.replace(
+                                            microsecond=int(
+                                                str(obj_updated_at.microsecond)[:3]
+                                            )
+                                        )
+                                        if obj_updated_at > updated_at:
+                                            raise HTTPPreconditionRequiredError
 
                             obj_obj = copy(obj)
 
