@@ -2,7 +2,7 @@ from typing import Any, Dict
 
 from tortoise import Tortoise
 
-from .base import BaseModel
+from .base import BaseModel, BaseUpdateModel
 from .enum import IntEnum, StrEnum, allow_eject
 from .recoverialbe import RecoverableModel
 
@@ -16,4 +16,11 @@ def init_models(config: Dict[str, Any]):
         Tortoise.init_models(info["models"], name)
 
 
-__all__ = ["StrEnum", "IntEnum", "allow_eject", "BaseModel", "RecoverableModel"]
+__all__ = [
+    "StrEnum",
+    "IntEnum",
+    "allow_eject",
+    "BaseModel",
+    "BaseUpdateModel",
+    "RecoverableModel",
+]
