@@ -4,11 +4,10 @@ from typing import Any, Dict, Optional
 from tortoise import fields
 from tortoise.backends.base.client import BaseDBAsyncClient
 
-from .base import BaseModel
+from .base import BaseUpdateModel
 
 
-class RecoverableModel(BaseModel):
-
+class RecoverableModel(BaseUpdateModel):
     is_deleted = fields.BooleanField(null=False, description="是否已经删除", default=False)
     delete_or_recover_at = fields.DatetimeField(null=True, description="删除时间")
 
